@@ -113,7 +113,11 @@ TkpUseWindow(interp, tkwin, string)
 	panic("TkUseWindow: X window already assigned");
     }
     if (Tcl_GetInt(interp, string, &id) != TCL_OK) {
-	return TCL_ERROR;
+        char *s = LangString(string);
+        char *e = NULL;
+	id = strtoul(s,&e,0);
+        if (!e || *e)
+	    return TCL_ERROR;
     }
     parent = (Window) id;
 
